<?php
/*
 * Plugin Name: WordPress Wishlist Collection & Bookmark Plugin
 * Plugin URI: http://redq.io/
 * Description: WordPress product wishlist, collction and bookmark plugin for customer.
 * Version: 2.1.0
 * Author: redqteam
 * Author URI: http://redq.io
 * Requires at least: 4.0
 * Tested up to: 4.7.5
 *
 * Text Domain: wwcb
 * Domain Path: /languages/
 *
 * Copyright: © 2015-2017 redqteam.
 * License: GNU General Public License v3.0
 * License URI: http://www.gnu.org/licenses/gpl-3.0.html
 *
 */

if(!defined('ABSPATH')) exit; // Exit if accessed directly
require_once( ABSPATH . 'wp-admin/includes/plugin.php' );

/**
 * Class Redq_WC_Wishlists_Collectison
 */
class WordPress_Wishlist_Collection_Bookmark {
  /**
   * Wishlist & Collection version.
   *
   * @var string
   */
  public $version = '2.1.0';
  /**
   * @var null
   */
  protected static $_instance = null;
  /**
   * @create instance on self
   */
  public static function instance() {
    if ( is_null( self::$_instance ) ) {
      self::$_instance = new self();
    }
    return self::$_instance;
  }


  public function __construct(){
    $this->app_bootstrap();
    $this->load_all_classes();
    $this->init_hooks();
    add_action( 'plugins_loaded', array( &$this, 'language_textdomain' ), 1 );
    do_action( 'wwcb_loaded' );
  } 

  public function init_hooks() {
    register_activation_hook( __FILE__, array( 'WWCB_Install', 'install' ) );
  }

  /**
   *  App Bootstrap
   *  Fire all class
   */
  public function app_bootstrap(){
    /**
     * Define plugin constant
     */
    if( !defined( 'WWCB_DIR' ) ){
      define( 'WWCB_DIR', untrailingslashit( plugin_dir_path( __FILE__ ) ) );
    }
    if( !defined( 'WWCB_URL' ) ){
      define( 'WWCB_URL', untrailingslashit( plugins_url( basename( plugin_dir_path( __FILE__ ) ), basename( __FILE__ ) ) ) );
    }
    if( !defined( 'WWCB_FILE' ) ){
      define( 'WWCB_FILE', dirname(__FILE__));
    }
    if( !defined( 'WWCB_CSS' ) ){
      define( 'WWCB_CSS' , WWCB_URL.'/assets/dist/css/' );
    }
    if( !defined( 'WWCB_CSS_VEN' ) ){
      define( 'WWCB_CSS_VEN' , WWCB_URL.'/assets/dist/style-vendor/' );
    }        
    if( !defined( 'WWCB_JS' ) ){
      define( 'WWCB_JS' ,  WWCB_URL.'/assets/dist/js/' );
    }
    if( !defined( 'WWCB_VENDOR_JS' ) ){
      define( 'WWCB_VENDOR_JS' ,  WWCB_URL.'/assets/dist/vendor/' );
    }        
    if( !defined( 'WWCB_IMG' ) ){
      define( 'WWCB_IMG' , WWCB_URL.'/assets/dist/img/' );
    }
    if( !defined( 'WWCB_JS_REUSE_FORM' ) ){
      define( 'WWCB_JS_REUSE_FORM' , WWCB_URL.'/assets/dist/reuse-form/' );
    }
    if( !defined( 'WWCB_INC' ) ){
      define( 'WWCB_INC' , WWCB_DIR.'/includes/' );
    }
    if( !defined( 'WWCB_ADMIN' ) ){
      define( 'WWCB_ADMIN' , WWCB_INC.'admin/' );
    }
    if( !defined( 'WWCB_TEMPLATE_PATH' ) ){
      define( 'WWCB_TEMPLATE_PATH', plugin_dir_path( __FILE__ ) . 'templates/' );
    }
  }

  /**
   * Load all the classes with composer auto loader
   *
   * @return void
   */
  public function load_all_classes(){
    require_once WWCB_INC . 'class-redq-wwc-install.php';
    require_once WWCB_ADMIN . 'class-redq-wwc-post-types.php';
    require_once WWCB_ADMIN . 'class-admin-menu.php';
    require_once WWCB_INC . 'class-wwcb-reuse-form.php';
    require_once WWCB_INC . 'class-redq-wwc-frontend-scripts.php';
    require_once WWCB_INC . 'class-redq-wwc-template-handle.php';
    require_once WWCB_INC . 'class-redq-wwc-template-loader.php';
    require_once WWCB_INC . 'class-redq-wwc-shortcode.php';
    require_once WWCB_INC . 'class-wwcb-wishlists.php';
    require_once WWCB_INC . 'class-redq-wwc-my-wishlists-query.php';
    require_once WWCB_INC . 'class-redq-wwc-collection-single-query.php';
    require_once WWCB_INC . 'class-redq-wwc-theme-support.php';
    require_once WWCB_INC . 'class-redq-wwc-collections.php';
    require_once WWCB_INC . 'redq-wwc-template-hooks.php';
    require_once WWCB_INC . 'redq-wwc-template-functions.php';
    require_once WWCB_INC . 'class-redq-wwc-localization.php';
    require_once WWCB_INC . 'class-redq-wwc-collection-main-query.php';
    require_once WWCB_INC . 'class-redq-bookmarks.php';
    if( class_exists('BuddyPress') ) {
      require_once WWCB_INC . 'class-redq-buddypress-support.php';
    }
    if ( class_exists('Vc_Manager') ) {
      require_once WWCB_INC . 'class-redq-wwc-vc-support.php';
    }
  }

  /**
   * Get the template path.
   * @return string
   */
  public function template_path() {
    return apply_filters( 'wwcb_template_path', 'wwcb/' );
  }

  /**
   * Get the template path.
   * @return string
   */
  public function template_path_name() {
    return apply_filters( 'wwcb_template_path_name', 'wwcb' );
  }

  /**
   * Get the plugin path.
   * @return string
   */
  public function plugin_path() {
    return untrailingslashit( plugin_dir_path( __FILE__ ) );
  }

  /**
   * Get the plugin textdomain for multilingual.
   * @return null
   */
  public function language_textdomain() {
    load_plugin_textdomain( 'wwcb', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );
  }
}
/**
 * Main instance of WordPress Wishlist Collection & Bookmark Plugin.
 *
 * Returns the main instance of WWCB to prevent the need to use globals.
 *
 * @since  1.0
 * @return WordPress_Wishlist_Collection_Bookmark
 */
function WWCB() {
  return WordPress_Wishlist_Collection_Bookmark::instance();
}
// Global for backwards compatibility.
$GLOBALS['wwcb'] = WWCB();
